@@ -4,6 +4,7 @@ import subprocess
 import sys
 
 from sysflow.utils.common_utils.file_utils import dump, is_empty, load
+import ruamel.yaml
 
 BASE_DIR = os.path.dirname(os.path.realpath(__file__))
 user_config = os.path.join(BASE_DIR, "slurm_user.yaml")
@@ -162,6 +163,7 @@ def config(args=None):
 
     slurm = Slurm(**args_dict)
 
+    status()
 
 def run(args=None):
     parser = argparse.ArgumentParser(
@@ -178,13 +180,20 @@ def run(args=None):
     slurm.run(command_line)
 
 
+def status(args=None):
+    print()
+    print('the current slurm configuration: ')
+    user_args_dict = load(user_config)
+    res = ''.join(ruamel.yaml.round_trip_dump(user_args_dict, indent=5, block_seq_indent=3).splitlines(True))
+    print(res)
+
 def main(args=None):
     parser = argparse.ArgumentParser(
         prog="slurm", description="A program to generate slurm command lines."
     )
     parser.add_argument(
         "command",
-        help="specify the sub-command to run, possible choices: " "config, run",
+        help="specify the sub-command to run, possible choices: " "config, run, show",
     )
     parser.add_argument(
         "args",
@@ -197,6 +206,8 @@ def main(args=None):
     # sepatate all sub_command to make them useable independently
     if args.command.upper() == "CONFIG":
         sub_command = config
+    elif args.command.upper() == "STATUS":
+        sub_command = status
     elif args.command.upper() == "RUN":
         sub_command = run
     else:
